"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __values = (this && this.__values) || function (o) {
    var m = typeof Symbol === "function" && o[Symbol.iterator], i = 0;
    if (m) return m.call(o);
    return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var CSSContext_1 = require("./CSSContext");
var isServer_1 = require("./utils/isServer");
function createCSSCollector(renderLoading, renderError, displayName) {
    if (displayName === void 0) { displayName = 'CSSCollector'; }
    var ScopedCSSCollector = function (props) {
        return (React.createElement(CSSContext_1.Consumer, null, function (context) { return (React.createElement(CSSCollectorLifecycle, __assign({ context: context, renderError: renderError, renderLoading: renderLoading }, props))); }));
    };
    ScopedCSSCollector.displayName = displayName;
    return ScopedCSSCollector;
}
exports.createCSSCollector = createCSSCollector;
exports.CSSCollector = createCSSCollector();
var CSSCollectorLifecycle = /** @class */ (function (_super) {
    __extends(CSSCollectorLifecycle, _super);
    function CSSCollectorLifecycle(props) {
        var _this = _super.call(this, props) || this;
        var context = props.context, hrefs = props.hrefs;
        // When this instance created, access context api.
        context.multiUpdate(hrefs);
        return _this;
    }
    /**
     * get Fetch State from state array.
     * @param {CSSFetchState[]} states
     * @return {CSSFetchState}
     */
    CSSCollectorLifecycle.getFetchState = function (states) {
        var e_1, _a;
        var isLoading;
        try {
            for (var states_1 = __values(states), states_1_1 = states_1.next(); !states_1_1.done; states_1_1 = states_1.next()) {
                var state = states_1_1.value;
                // if some error state, return Error.
                if (state === CSSContext_1.CSSFetchState.Error) {
                    return CSSContext_1.CSSFetchState.Error;
                }
                if (state === CSSContext_1.CSSFetchState.Loading || !state) {
                    isLoading = true;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (states_1_1 && !states_1_1.done && (_a = states_1.return)) _a.call(states_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        if (isLoading) {
            return CSSContext_1.CSSFetchState.Loading;
        }
        else {
            return CSSContext_1.CSSFetchState.Success;
        }
    };
    CSSCollectorLifecycle.prototype.render = function () {
        var _a = this.props, context = _a.context, hrefs = _a.hrefs;
        var state = CSSCollectorLifecycle.getFetchState(hrefs.map(function (href) {
            return context.cssMap.get(href);
        }));
        // if SSR, it should be render.
        if (state === CSSContext_1.CSSFetchState.Success || isServer_1.isServer()) {
            return React.createElement(React.Fragment, null, this.props.children);
        }
        if (state === CSSContext_1.CSSFetchState.Loading || !state) {
            return this.props.renderLoading ? this.props.renderLoading() : null;
        }
        if (state === CSSContext_1.CSSFetchState.Error) {
            return this.props.renderError ? this.props.renderError() : null;
        }
        return null;
    };
    return CSSCollectorLifecycle;
}(React.Component));
//# sourceMappingURL=CSSCollector.js.map