"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var CSSContext_1 = require("./CSSContext");
var appendCSS_1 = require("./utils/appendCSS");
var isServer_1 = require("./utils/isServer");
var CSSProvider = /** @class */ (function (_super) {
    __extends(CSSProvider, _super);
    /**
     * @constructor
     * @param {Readonly<CSSProviderProps>} props
     */
    function CSSProvider(props) {
        var _this = _super.call(this, props) || this;
        /**
         * update CSS-Map in CSSContext.
         * @param {string} href
         */
        _this.update = function (href) {
            if (isServer_1.isServer()) {
                // if SSR
                // CSSCollector always pass the CSSLoadingState in SSR phase.
                // Then override the CSS-Map which is defined before server side rendering.
                _this.props.cssMap.set(href, CSSContext_1.CSSFetchState.Success);
            }
            else {
                // if CSR
                // CSSCollector state is default Loading. (when css is not append yet.)
                // Append the link element with css.
                // When css file’s have been loaded, CSSCollector state will change to Success.
                // or if error, CSSCollector state will be Error.
                if (_this.state.cssMap.get(href) !== CSSContext_1.CSSFetchState.Success) {
                    appendCSS_1.appendCSS(href, function () {
                        _this.updateCSSMap(href, CSSContext_1.CSSFetchState.Success);
                    }, function () {
                        _this.updateCSSMap(href, CSSContext_1.CSSFetchState.Error);
                    });
                }
            }
        };
        /**
         * multiple update CSS-Map in CSSContext.
         * @param {string[]} hrefs
         */
        _this.multiUpdate = function (hrefs) {
            hrefs.forEach(function (href) {
                _this.update(href);
            });
        };
        _this.state = {
            cssMap: props.cssMap,
            multiUpdate: _this.multiUpdate,
            update: _this.update,
        };
        return _this;
    }
    /**
     * set new CSS-Map state.
     * @param {string} href
     * @param {CSSFetchState} state
     */
    CSSProvider.prototype.updateCSSMap = function (href, state) {
        // create new CSS-Map to avoid override refs.
        var cssMap = new Map(this.state.cssMap.entries());
        cssMap.set(href, state);
        this.setState({
            cssMap: cssMap,
        });
    };
    CSSProvider.prototype.render = function () {
        return (React.createElement(CSSContext_1.Provider, { value: this.state }, React.Children.only(this.props.children)));
    };
    return CSSProvider;
}(React.Component));
exports.CSSProvider = CSSProvider;
//# sourceMappingURL=CSSProvider.js.map